@@ -11,7 +11,7 @@ namespace cpputils {
 TempFile::TempFile(const bf::path &path, bool create)
   : _path(path) {
   if (create) {
-    ofstream file(_path.c_str());
+    ofstream file(_path.string().c_str());
     if (!file.good()) {
       throw std::runtime_error("Could not create tempfile");
     }
@@ -25,13 +25,17 @@ TempFile::TempFile(bool create)
 TempFile::~TempFile() {
   try {
     if (exists()) {
-      bf::remove(_path);
+      remove();
     }
   } catch (const boost::filesystem::filesystem_error &e) {
-    LOG(ERROR, "Could not delete tempfile.");
+    LOG(ERR, "Could not delete tempfile.");
   }
 }
 
+void TempFile::remove() {
+  bf::remove(_path);
+}
+
 bool TempFile::exists() const {
   return bf::exists(_path);
 }
