@@ -3,15 +3,16 @@
 #define MESSMER_FSPP_TEST_FUSE_CREATEANDOPENFILE_TESTUTILS_FUSECREATEANDOPENTEST_H_
 
 #include "../../../testutils/FuseTest.h"
+#include "../../../testutils/OpenFileHandle.h"
 
 class FuseCreateAndOpenTest: public FuseTest {
 public:
   const char *FILENAME = "/myfile";
 
-  int CreateAndOpenFile(const char *FILENAME, int flags);
-  int CreateAndOpenFileReturnError(const char *FILENAME, int flags);
+  void CreateAndOpenFile(const std::string& FILENAME, int flags);
+  int CreateAndOpenFileReturnError(const std::string& FILENAME, int flags);
 private:
-  int CreateAndOpenFileAllowError(const char *FILENAME, int flags);
+  cpputils::unique_ref<OpenFileHandle> CreateAndOpenFileAllowErrors(const TempTestFS *fs, const std::string &filename, int flags);
 };
 
 MATCHER_P(OpenFlagsEq, expectedFlags, "") {
