@@ -5,13 +5,13 @@ using ::testing::Values;
 
 class FuseLstatReturnModeTest: public FuseLstatTest, public WithParamInterface<mode_t> {
 public:
-  struct stat CallLstatWithValue(mode_t mode) {
-    return CallLstatWithImpl([mode] (struct stat *stat) {
+  fspp::fuse::STAT CallLstatWithValue(mode_t mode) {
+    return CallLstatWithImpl([mode] (fspp::fuse::STAT *stat) {
       stat->st_mode = mode;
     });
   }
 };
-INSTANTIATE_TEST_CASE_P(FuseLstatReturnModeTest, FuseLstatReturnModeTest, Values(
+INSTANTIATE_TEST_SUITE_P(FuseLstatReturnModeTest, FuseLstatReturnModeTest, Values(
     S_IFREG,
     S_IFDIR,
     S_IFREG | S_IRUSR | S_IWGRP | S_IXOTH, // a file with some access bits set
@@ -19,6 +19,6 @@ INSTANTIATE_TEST_CASE_P(FuseLstatReturnModeTest, FuseLstatReturnModeTest, Values
 ));
 
 TEST_P(FuseLstatReturnModeTest, ReturnedModeIsCorrect) {
-  struct ::stat result = CallLstatWithValue(GetParam());
+  fspp::fuse::STAT result = CallLstatWithValue(GetParam());
   EXPECT_EQ(GetParam(), result.st_mode);
 }
