@@ -12,7 +12,7 @@ int FuseMkdirTest::MkdirReturnError(const char *dirname, mode_t mode) {
   auto fs = TestFS();
 
   auto realpath = fs->mountDir() / dirname;
-  int retval = ::mkdir(realpath.c_str(), mode);
+  int retval = ::mkdir(realpath.string().c_str(), mode);
   if (retval == 0) {
     return 0;
   } else {
@@ -20,8 +20,8 @@ int FuseMkdirTest::MkdirReturnError(const char *dirname, mode_t mode) {
   }
 }
 
-Action<void(const char*, mode_t, uid_t, gid_t)> FuseMkdirTest::FromNowOnReturnIsDirOnLstat() {
-  return Invoke([this](const char *dirname, mode_t, uid_t, gid_t) {
+Action<void(const boost::filesystem::path&, mode_t, uid_t, gid_t)> FuseMkdirTest::FromNowOnReturnIsDirOnLstat() {
+  return Invoke([this](const boost::filesystem::path& dirname, mode_t, uid_t, gid_t) {
     ReturnIsDirOnLstat(dirname);
   });
 }
