@@ -1,6 +1,6 @@
 #include "testutils/FuseReadDirTest.h"
 
-using ::testing::StrEq;
+using ::testing::Eq;
 
 using std::string;
 
@@ -9,7 +9,7 @@ public:
 };
 
 TEST_F(FuseReadDirDirnameTest, ReadRootDir) {
-  EXPECT_CALL(*fsimpl, readDir(StrEq("/")))
+  EXPECT_CALL(*fsimpl, readDir(Eq("/")))
     .Times(1).WillOnce(ReturnDirEntries({}));
 
   ReadDir("/");
@@ -17,7 +17,7 @@ TEST_F(FuseReadDirDirnameTest, ReadRootDir) {
 
 TEST_F(FuseReadDirDirnameTest, ReadDir) {
   ReturnIsDirOnLstat("/mydir");
-  EXPECT_CALL(*fsimpl, readDir(StrEq("/mydir")))
+  EXPECT_CALL(*fsimpl, readDir(Eq("/mydir")))
     .Times(1).WillOnce(ReturnDirEntries({}));
 
   ReadDir("/mydir");
@@ -26,7 +26,7 @@ TEST_F(FuseReadDirDirnameTest, ReadDir) {
 TEST_F(FuseReadDirDirnameTest, ReadDirNested) {
   ReturnIsDirOnLstat("/mydir");
   ReturnIsDirOnLstat("/mydir/mydir2");
-  EXPECT_CALL(*fsimpl, readDir(StrEq("/mydir/mydir2")))
+  EXPECT_CALL(*fsimpl, readDir(Eq("/mydir/mydir2")))
     .Times(1).WillOnce(ReturnDirEntries({}));
 
   ReadDir("/mydir/mydir2");
@@ -36,7 +36,7 @@ TEST_F(FuseReadDirDirnameTest, ReadDirNested2) {
   ReturnIsDirOnLstat("/mydir");
   ReturnIsDirOnLstat("/mydir/mydir2");
   ReturnIsDirOnLstat("/mydir/mydir2/mydir3");
-  EXPECT_CALL(*fsimpl, readDir(StrEq("/mydir/mydir2/mydir3")))
+  EXPECT_CALL(*fsimpl, readDir(Eq("/mydir/mydir2/mydir3")))
     .Times(1).WillOnce(ReturnDirEntries({}));
 
   ReadDir("/mydir/mydir2/mydir3");
